
class Template:

  template_model = dict(

  Birthdate = dict(
    processURI = "http://purl.obolibrary.org/obo/NCIT_C142470",
    outputURI = "http://www.ebi.ac.uk/efo/EFO_0006921",
    attributeURI = "http://purl.obolibrary.org/obo/NCIT_C68615",
    valueAttributeIRI = None,
    value = None,
    datatype = "xsd:date",
    startdate = None,
    enddate = None,
    pid = None,
    context_id = None
  ),


  Sex = dict( 
    processURI = "http://purl.obolibrary.org/obo/NCIT_C142470",
    outputURI = "http://purl.obolibrary.org/obo/NCIT_C103159",
    attributeURI = "http://purl.obolibrary.org/obo/NCIT_C28421",
    valueAttributeIRI = None,
    value = None,
    datatype = "xsd:string",
    startdate = None,
    enddate = None,
    pid = None,
    context_id = None
  ),


  Status = dict(
    processURI= "http://purl.obolibrary.org/obo/NCIT_C142470",
    outputURI= "http://purl.obolibrary.org/obo/NCIT_C103159",
    attributeURI= "http://purl.obolibrary.org/obo/NCIT_C166244",
    valueAttributeIRI = None,
    value = None,
    datatype = "xsd:string",
    startdate = None,
    enddate = None,
    pid = None,
    context_id = None
  ),

  Date_of_death = dict( 
    processURI= "http://purl.obolibrary.org/obo/NCIT_C142470",
    outputURI= "http://purl.obolibrary.org/obo/NCIT_C103159",
    attributeURI= "http://purl.obolibrary.org/obo/NCIT_C70810",
    valueAttributeIRI = None,
    value = None,
    datatype = "xsd:date",
    startdate = None,
    enddate = None,
    pid = None,
    context_id = None
  ),

  Care_pathway = dict(
    processURI= "http://purl.obolibrary.org/obo/NCIT_C159705",
    outputURI= "http://purl.obolibrary.org/obo/NCIT_C25716",
    attributeURI= "http://purl.obolibrary.org/obo/NCIT_C164021",
    valueAttributeIRI = None,
    value = None,
    datatype = "xsd:date",
    startdate = None,
    enddate = None,
    pid = None,
    context_id = None
  ),

  Diagnosis = dict(
    processURI= "http://purl.obolibrary.org/obo/NCIT_C15220",
    outputURI= "http://purl.obolibrary.org/obo/NCIT_C103159",
    attributeURI= "http://purl.obolibrary.org/obo/NCIT_C2991",
    valueAttributeIRI = None,
    value = None,
    datatype = "xsd:string",
    startdate = None,
    enddate = None,
    pid = None,
    context_id = None
  ),

  Date_of_diagnosis = dict(
    processURI= "http://purl.obolibrary.org/obo/NCIT_C142470",
    outputURI = None,
    attributeURI= "http://purl.obolibrary.org/obo/NCIT_C156420",
    valueAttributeIRI = None,
    value = None,
    datatype = "xsd:date",
    startdate = None,
    enddate = None,
    pid = None,
    context_id = None
  ),

  Date_of_symptoms = dict(
    processURI= "http://purl.obolibrary.org/obo/NCIT_C142470",
    outputURI = None,
    attributeURI= "http://purl.obolibrary.org/obo/NCIT_C25279",
    valueAttributeIRI = None,
    value = None,
    datatype = "xsd:date",
    startdate = None,
    enddate = None,
    pid = None,
    context_id = None
  ),

  Phenotype = dict(
    processURI= "http://purl.obolibrary.org/obo/NCIT_C25305",
    outputURI= "http://purl.obolibrary.org/obo/NCIT_C125204",
    attributeURI= "http://semanticscience.org/resource/SIO_010056",
    valueAttributeIRI = None,
    value = None,
    datatype = "xsd:date",
    startdate = None,
    enddate = None,
    pid = None,
    context_id = None
  ),

  Genotype = dict(
    processURI= "http://purl.obolibrary.org/obo/NCIT_C15709",
    outputURI= "http://purl.obolibrary.org/obo/NCIT_C17248",
    attributeURI= None,
    valueAttributeIRI = None,
    value = None,
    datatype = "xsd:string",
    startdate = None,
    enddate = None,
    pid = None,
    context_id = None
  ),

  Genotype_OMIM = dict(
    processURI= "http://purl.obolibrary.org/obo/NCIT_C15709",
    outputURI= "http://purl.obolibrary.org/obo/NCIT_C17248",
    attributeURI= "http://edamontology.org/data_1153",
    valueAttributeIRI = None,
    value = None,
    datatype = "xsd:string",
    startdate = None,
    enddate = None,
    pid = None,
    context_id = None
  ),

  Genotype_HGNC = dict(
    processURI= "http://purl.obolibrary.org/obo/NCIT_C15709",
    outputURI= "http://purl.obolibrary.org/obo/NCIT_C17248",
    attributeURI= "http://edamontology.org/data_2295",
    valueAttributeIRI = None,
    value = None,
    datatype = "xsd:string",
    startdate = None,
    enddate = None,
    pid = None,
    context_id = None
  ),

  Consent = dict(
    processURI= "http://purl.obolibrary.org/obo/OBI_0000810",
    outputURI = None,
    attributeURI= "http://purl.obolibrary.org/obo/NCIT_C25460",
    valueAttributeIRI = None,
    value = None,
    datatype = "xsd:string",
    startdate = None,
    enddate = None,
    pid = None,
    context_id = None
  ),

  Biobank = dict(
    processURI= "http://purl.obolibrary.org/obo/OMIABIS_0000061",
    outputURI= "http://purl.obolibrary.org/obo/NCIT_C115570",
    attributeURI= "http://purl.obolibrary.org/obo/NCIT_C25429",
    valueAttributeIRI = None,
    value = None,
    datatype = "xsd:string",
    startdate = None,
    enddate = None,
    pid = None,
    context_id = None
  ),

  Disability = dict(
    processURI = None,
    outputURI= "http://purl.obolibrary.org/obo/NCIT_C25338",
    attributeURI= "http://purl.obolibrary.org/obo/NCIT_C21007",
    valueAttributeIRI = None,
    value = None,
    datatype = "xsd:float",
    startdate = None,
    enddate = None,
    pid = None,
    context_id = None
  )
  )




# -*- coding: utf-8 -*-
from setuptools import setup
# with open('README.md') as readme_file:
#     readme = readme_file.read()

# with open('requirements.txt') as f:
#     requirements = f.read().splitlines()

setup(
    name="Hefesto",
    version="0.2.1",
    packages=["Hefesto"],
    author="Pablo Alarcón Moreno",
    author_email="pabloalarconmoreno@gmail.com",
    url="https://github.com/pabloalarconm/hefesto",
    description="Preprocessing datatable toolkit",
    license="MIT",
    keywords=["EJP","CDE"]
)